# Sintel

## Rendering

::: flyvis.datasets.sintel.RenderedSintel

## Datasets

::: flyvis.datasets.sintel.MultiTaskSintel

::: flyvis.datasets.sintel.AugmentedSintel

## Utils

::: flyvis.datasets.sintel_utils
